Xlsxir v1.3.4 Xlsxir.Index
An Agent process named Index which holds state of an index. Provides functions to create the process, increment the index by 1, retrieve the current index
and ultimately kill the process.
Summary
Functions
Deletes Index Agent process
Returns current value of Index Agent process
Increments active Index Agent process by 1
Initiates a new Index Agent process with a value of 0