Xlsxir v1.3.4
Xlsxir.TableId
An Agent process named TableId which temporarily holds the table id of an ETS process. Provides functions to create the process, assign a table id, retrieve the current table id
and ultimately kill the process.
Summary
Assigns an ETS table id to the TableId Agent process
Deletes TableId Agent process
Returns current value of TableId Agent process
Initiates a new TableId Agent process with a value of 0
Functions
Assigns an ETS table id to the TableId Agent process.
Deletes TableId Agent process
Returns current value of TableId Agent process
Initiates a new TableId Agent process with a value of 0.