Xlsxir v1.5.1 Xlsxir.Worksheet
An Erlang Term Storage (ETS) process named :worksheet which holds state for data parsed from sheet#{n}.xml at index n. Provides functions to create the process, add
and retreive data, and ultimately kill the process.
Summary
Functions
Stores a row at a given index in the ETS process
Validates whether the ETS process is active, returning true or false
Deletes the ETS process from memory
Returns a row at a given index of the ETS process
Initializes new ETS process with [:set, :protected, :named_table] options
Initializes new ETS process with [:set, :protected] options and assigns the associated table id to Xlsxir.TableId
Functions
Initializes new ETS process with [:set, :protected] options and assigns the associated table id to Xlsxir.TableId.